/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.myfaces.extensions.validator.core.validation.parameter;

import org.apache.myfaces.extensions.validator.internal.UsageInformation;
import org.apache.myfaces.extensions.validator.internal.UsageCategory;

import java.lang.annotation.Target;
import java.lang.annotation.Retention;
import static java.lang.annotation.RetentionPolicy.RUNTIME;
import static java.lang.annotation.ElementType.FIELD;
import static java.lang.annotation.ElementType.METHOD;

/**
 * Marker for values within a
 * {@link org.apache.myfaces.extensions.validator.core.validation.parameter.ValidationParameter} implementation.
 *
 * @since x.x.3
 */
@Target({FIELD, METHOD})
@Retention(RUNTIME)
@UsageInformation(UsageCategory.API)
public @interface ParameterValue
{
    /**
     * It's possible to define multiple values within the
     * {@link org.apache.myfaces.extensions.validator.core.validation.parameter.ValidationParameter} implementation with
     * the same type. The optional id allows to identify the value of interest.
     *
     * @return the type-safe id
     */
    Class id() default ParameterValue.class;
}
